library reader_tests;

import 'package:qv_exp/src/reader.dart' as qv;
import 'package:unittest/unittest.dart';
void main() {
  test('test_simplest', () {
    var code = r'''
VariableName,VariableValue,Comments,Priority
SET СуммаПродажи,"Money(Sum({$<ТипДокумента={2}, ТипПериода={'Current'}>}Сумма),'# ##0,00')",,
SET СуммаПродажи.Comment,Сумма продаж в руб.,,
''';  
    var reader = new qv.Reader()..readFile('CustomVariables.qsv',code);
    expect(reader.expressions.length, 1);
    expect(reader.expressions.values.first.name,'СуммаПродажи');
    expect(reader.expressions.values.first.sourceText,r"Money(Sum({$<ТипДокумента={2}, ТипПериода={'Current'}>}Сумма),'# ##0,00')");
  });
  test('Test variable expansion', () {
    var code = r'''
VariableName,VariableValue,Comments,Priority
SET ПФ_Продажи,"Money($(СуммаПродажи)/$(ПланПродаж),'# ##0,0%')",,
SET СуммаПродажи,"Money(Sum({$<ТипДокумента={2}, ТипПериода={'Current'}>}Сумма),'# ##0,00')",,
SET ПланПродаж,"Money(Sum({<_ФлагДействующаяДата={1},ТипДокумента={13},ТипПериода={'Current'}>} Сумма),'# ##0,00')",,
''';
    var reader = new qv.Reader()..readFile('CustomVariables.qsv',code);
    expect(reader.expressions.length, 3);
    expect(reader.errors.isEmpty,isTrue);
    expect(reader.expressions['ПФ_Продажи'].expandedText, startsWith(r'Money(Money(Sum({$<ТипДокумента={2}'));
  });
  test('Test variable expansion with absent variable', () {
    var code = r'''
VariableName,VariableValue,Comments,Priority
SET ПФ_Продажи,"Money($(СуммаПродажи)/$(ПланПродаж),'# ##0,0%')",,
SET СуммаПродажи1,"Money(Sum({$<ТипДокумента={2}, ТипПериода={'Current'}>}Сумма),'# ##0,00')",,
SET ПланПродаж,"Money(Sum({<_ФлагДействующаяДата={1},ТипДокумента={13},ТипПериода={'Current'}>} Сумма),'# ##0,00')",,
''';
    var reader = new qv.Reader()..readFile('CustomVariables.qsv',code);
    expect(reader.expressions.length, 3);
    expect(reader.errors.isEmpty,isFalse);
    expect(reader.expressions['ПФ_Продажи'].expandedText, startsWith(r'Money(/'));
  });

  skip_test('Test real codebase', () {
    var code = r'''
VariableName,VariableValue,Comments,Priority
SET vU.CurrentDate,1313,,
SET СуммаПродажи,"Money(Sum({$<ТипДокумента={2}, ТипПериода={'Current'}>}Сумма),'# ##0,00')",,
SET СуммаПродажи.Comment,Сумма продаж в руб.,,
SET СуммаПродажи.Label,"Продажи, руб.",,
SET СуммаПродажиТыс,"Money(Sum({$<ТипДокумента={2}, ТипПериода={'Current'}>}Сумма)/1000,'# ##0,00')",,
SET СуммаПродажиТыс.Comment,Сумма продаж в тыс. руб.,,
SET СуммаПродажиТыс.Label,Продажи в тыс. руб.,,
SET ПланПродаж,"Money(Sum({<_ФлагДействующаяДата={1},ТипДокумента={13},ТипПериода={'Current'}>} Сумма),'# ##0,00')",,
SET ПланПродаж.Comment,План Продаж (за неполный месяц)  руб.,,
SET ПланПродаж.Label,"План Продаж, руб.",,
SET ПланПродажТыс,"Money(Sum({<_ФлагДействующаяДата={1},ТипДокумента={13},ТипПериода={'Current'}>} Сумма)/1000,'# ##0,00')",,
SET ПланПродажТыс.Comment,План Продаж (за неполный месяц) в тыс. руб.,,
SET ПланПродажТыс.Label,План Продаж в тыс. руб.,,
SET ПланПродажПолный,"Money(Sum({<ТипДокумента={13},ТипПериода={'Current'}>} Сумма),'# ##0,00')",,
SET ПланПродажПолный.Comment,План Продаж (за полный месяц)  руб.,,
SET ПланПродажПолный.Label,"План Продаж за полный месяц, руб.",,
SET ПланПродажПолныйТыс,"Money(Sum({<ТипДокумента={13},ТипПериода={'Current'}>} Сумма)/1000,'# ##0,00')",,
SET ПланПродажПолныйТыс.Comment,План Продаж (за полный месяц)  в тыс. руб.,,
SET ПланПродажПолныйТыс.Label,"План Продаж за полный месяц, в тыс. руб.",,
SET ПФ_Продажи,"Money($(СуммаПродажи)/$(ПланПродаж),'# ##0,0%')",,
SET ПФ_Продажи.Comment,Факт отнесенный к плану по продажам,,
SET ПФ_Продажи.Label,ПФ Продажи,,
SET П_Ф_Продажи,"Money(($(СуммаПродажи)-$(ПланПродаж)),'# ##0,00')",,
SET П_Ф_Продажи.Comment,"План минус факт по продажам, руб.",,
SET П_Ф_Продажи.Label,"П-Ф Продажи, руб.",,
SET П_Ф_ПродажиТыс,"Money(($(СуммаПродажи)-$(ПланПродаж))/1000,'# ##0,00')",,
SET П_Ф_ПродажиТыс.Comment,План минус факт по продажам тыс. руб.,,
SET П_Ф_ПродажиТыс.Label,П-Ф Продажи тыс. руб.,,
SET ПродажиПредГод,"Money(sum({<ТипДокумента = {2},_ФлагДействующаяДата={1}, ТипПериода={'Год'}>}Сумма)/1000,'# ##0,00')",,
SET ПродажиПредГод.Comment,Cумма продажи за предыдущий год тыс.руб.,,
SET ПродажиПредГод.Label,Продажи тыс.руб. пред год,,
SET ПродажиПредГод2,"Money((sum({<ТипДокумента = {2},_ФлагДействующаяДата={1}, ТипПериода={'Год-2'}>}Сумма)/1000),'# ##0,00')",,
SET ПродажиПредГод2.Comment,Cумма продажи за предпредыдущий год тыс.руб.,,
SET ПродажиПредГод2.Label,Продажи тыс.руб. предпред год,,
SET ПроцентПродажиПредГод,"Money($(СуммаПродажиТыс)/$(ПродажиПредГод),'# ##0,00%')",,
SET ПроцентПродажиПредГод.Comment,Процент Продажи к предыдущему году,,
SET ПроцентПродажиПредГод.Label,% Продажи к пред год,,
SET ПроцентПродажиПредГод2,"Money($(СуммаПродажиТыс)/$(ПродажиПредГод2),'# ##0,00%')",,
SET ПроцентПродажиПредГод2.Comment,Процент Продажи к предпредыдущему году,,
SET ПроцентПродажиПредГод2.Label,% Продажи к предпред год,,
SET СуммаРостаПродажиПредГод,"Money($(СуммаПродажиТыс)-$(ПродажиПредГод),'# ##0,00')",,
SET СуммаРостаПродажиПредГод.Comment,Сумма роста Продажи к предыдущему году,,
SET СуммаРостаПродажиПредГод.Label,Сумма роста Продаж к пред год,,
SET СуммаРостаПродажиПредГод2,"Money($(СуммаПродажиТыс)-$(ПродажиПредГод2),'# ##0,00')",,
SET СуммаРостаПродажиПредГод2.Comment,Сумма роста Продажи к предпредыдущему году,,
SET СуммаРостаПродажиПредГод2.Label,Сумма роста Продаж к предпред год,,
SET ПродажиПредМес,"Money(sum({<ТипДокумента = {2},_ФлагДействующаяДата={1}, ТипПериода={'ГодМесяц'}>}Сумма)/1000,'# ##0,00')",,
SET ПродажиПредМес.Comment,Cумма продажи за предыдущий мес тыс.руб.,,
SET ПродажиПредМес.Label,Продажи тыс.руб. пред мес,,
SET ПроцентПродажиПредМес,"Money($(СуммаПродажиТыс)/$(ПродажиПредМес),'# ##0,00%')",,
SET ПроцентПродажиПредМес.Comment,Процент Продажи к предыдущему месяцу,,
SET ПроцентПродажиПредМес.Label,% Продажи к пред мес,,
SET СуммаРостаПродажиПредМес,"Money($(СуммаПродажиТыс)-$(ПродажиПредМес),'# ##0,00')",,
SET СуммаРостаПродажиПредМес.Comment,Сумма роста Продажи к предыдущему месяцу,,
SET СуммаРостаПродажиПредМес.Label,Сумма роста Продаж к пред мес,,
SET ПродажиКоличество,"Money(Sum({$<ТипДокумента ={2},ТипПериода={'Current'}>}Количество),'# ##0,0000')",,
SET ПродажиКоличество.Comment,Количество проданного товара,,
SET ПродажиКоличество.Label,Кол Продано,,
SET ПродажиКоличествоБезШкалыЛиквидности,"Money(Sum({$<ТипДокумента ={2},ШкалаЛиквидности,ТипПериода={'Current'}>}Количество),'# ##0,0000')",,
SET ПродажиКоличествоБезШкалыЛиквидности.Comment,Количество проданного товара,,
SET ПродажиКоличествоБезШкалыЛиквидности.Label,Кол Продано,,
SET ДнейВПериоде,Floor((Max({<_ФлагДействующаяДата={1}>} TOTAL Дата)-Min({<_ФлагДействующаяДата={1}>}  TOTAL Дата)+1)/3),,
SET УсловиеПериод1,"Дата={"">$(=Date(Max({<_ФлагДействующаяДата={1}>} TOTAL Дата)-$(ДнейВПериоде)))<=$(=Date(Max({<_ФлагДействующаяДата={1}>} TOTAL Дата)))""}",,
SET УсловиеПериод2,"Дата={"">$(=Date(Max({<_ФлагДействующаяДата={1}>} TOTAL Дата)-$(ДнейВПериоде)*2))<=$(=Date(Max({<_ФлагДействующаяДата={1}>} TOTAL Дата)-$(ДнейВПериоде)))""}",,
SET УсловиеПериод3,"Дата={"">$(=Date(Max({<_ФлагДействующаяДата={1}>} TOTAL Дата)-$(ДнейВПериоде)*3))<=$(=Date(Max({<_ФлагДействующаяДата={1}>} TOTAL Дата)-$(ДнейВПериоде)*2))""}",,
SET УсловиеПериод4,"Дата={"">=$(=Date(Min({<_ФлагДействующаяДата={1}>} TOTAL Дата)))<=$(=Date(Max({<_ФлагДействующаяДата={1}>} TOTAL Дата)-$(ДнейВПериоде)*3))""}",,
SET ПродажиКоличествоПериод1,"Money(Sum({$<ТипДокумента={2},ТипПериода={'Current'},$(УсловиеПериод1)>}Количество),'# ##0')",,
SET ПродажиКоличествоПериод1Заголовок,'Продажи c '  & Min({<$(УсловиеПериод1)>} Дата) & ' по ' & Max({<$(УсловиеПериод1)>} Дата),,
SET ПродажиКоличествоПериод2,"Money(Sum({$<ТипДокумента={2},ТипПериода={'Current'},$(УсловиеПериод2)>}Количество),'# ##0')",,
SET ПродажиКоличествоПериод2Заголовок,'Продажи c '  & Min({<$(УсловиеПериод2)>} Дата) & ' по ' & Max({<$(УсловиеПериод2)>} Дата),,
SET ПродажиКоличествоПериод3,"Money(Sum({$<ТипДокумента={2},ТипПериода={'Current'},$(УсловиеПериод3)>}Количество),'# ##0')",,
SET ПродажиКоличествоПериод3Заголовок,'Продажи c '  & Min({<$(УсловиеПериод3)>} Дата) & ' по ' & Max({<$(УсловиеПериод3)>} Дата),,
SET ПродажиКоличествоПериод4,"Money(Sum({$<ТипДокумента={2},ТипПериода={'Current'},$(УсловиеПериод4)>}Количество),'# ##0')",,
SET ПродажиКоличествоПериод4Заголовок,'Продажи c '  & Min({<$(УсловиеПериод4)>} Дата) & ' по ' & Max({<$(УсловиеПериод4)>} Дата),,
SET УсловиеПоказаПериод4,"Max(Дата)-Min(Дата)>3 AND Mod(Max(Дата)-Min(Дата)+1,3)",,
SET ПродажиКоличествоПредГод,"Money(sum({<ТипДокумента = {2},_ФлагДействующаяДата={1}, ТипПериода={'Год'}>}Количество),'# ##0')",,
SET ПродажиКоличествоПредГод.Comment,Количество продано за предыдущий год,,
SET ПродажиКоличествоПредГод.Label,Продажи количество пред год,,
SET ПроцентПродажиКоличествоПредГод,"Money($(ПродажиКоличество)/$(ПродажиКоличествоПредГод),'# ##0,00%')",,
SET ПроцентПродажиКоличествоПредГод.Comment,Процент Количество проданных к предыдущему году,,
SET ПроцентПродажиКоличествоПредГод.Label,% Количество продано к пред год,,
SET СуммаВП,"Money(Sum({$<ТипДокумента = {2},ТипПериода={'Current'}>} ВП),'# ##0,00')",,
SET СуммаВП.Comment,Сумма продажи за вычетом себестоимости с НДС,,
SET СуммаВП.Label,Валовая Прибыль,,
SET СуммаВПТыс,"Money($(СуммаВП)/1000,'# ##0,00')",,
SET СуммаВПТыс.Comment,Сумма продажи за вычетом себестоимости в тыс. руб.,,
SET СуммаВПТыс.Label,Валовая Прибыль тыс.руб.,,
SET ПланВП,"Money(Sum({<_ФлагДействующаяДата={1},ТипДокумента={13},ТипПериода={'Current'}>} ВП),'# ##0,00')",,
SET ПланВП.Comment,План ВП (за неполный месяц)  руб.,,
SET ПланВП.Label,"План Валовой Прибыли, руб.",,
SET ПланВПТыс,"Money(Sum({<_ФлагДействующаяДата={1},ТипДокумента={13},ТипПериода={'Current'}>} ВП)/1000,'# ##0,00')",,
SET ПланВПТыс.Comment,План Валовой Прибыли (за неполный месяц) тыс. руб.,,
SET ПланВПТыс.Label,"План Валовой Прибыли, тыс руб.",,
SET ПланВППолный,"Money(Sum({<ТипДокумента={13},ТипПериода={'Current'}>} ВП),'# ##0,00')",,
SET ПланВППолный.Comment,План ВП (за полный месяц)  руб.,,
SET ПланВППолный.Label,"План Валовой Прибыли полный месяц, руб.",,
SET ПланВППолныйТыс,"Money(Sum({<ТипДокумента={13},ТипПериода={'Current'}>} ВП)/1000,'# ##0,00')",,
SET ПланВППолныйТыс.Comment,План Валовой Прибыли (за полный месяц) тыс. руб.,,
SET ПланВППолныйТыс.Label,"План Валовой Прибыли полный месяц, тыс. руб.",,
SET ПФ_ВП,"Money($(СуммаВП)/$(ПланВП),'# ##0,0%')",,
SET ПФ_ВП.Comment,Факт отнесенный к плану по валовой прибыли,,
SET ПФ_ВП.Label,% ПФ Валовой Прибыли,,
SET П_Ф_ВП,"Money($(СуммаВП)-$(ПланВП),'# ##0,0')",,
SET П_Ф_ВП.Comment,Факт отнесенный к плану по валовой прибыли,,
SET П_Ф_ВП.Label,П-Ф Валовой Прибыли,,
SET П_Ф_ВПТыс,"Money(($(СуммаВП)-$(ПланВП))/1000,'# ##0,0')",,
SET П_Ф_ВПТыс.Comment,Факт отнесенный к плану по валовой прибыли тыс. руб.,,
SET П_Ф_ВПТыс.Label,П-Ф Валовой Прибыли тыс. руб.,,
SET ВППредГод,"Num((sum({<ТипДокумента = {2}, _ФлагДействующаяДата={1},ТипПериода={'Год'}>}ВП)/1000),'# ##0,00')",,
SET ВППредГод.Comment,Валовая Прибыль за в предыдущий год тыс.руб.,,
SET ВППредГод.Label,Валовая Прибыль тыс.руб. пред год,,
SET ПроцентВППредГод,"Num($(СуммаВПТыс)/$(ВППредГод),'# ##0,00%')",,
SET ПроцентВППредГод.Comment,Процент Валовой Прибыли к предыдущему году,,
SET ПроцентВППредГод.Label,% Валовой Прибыли к пред году,,
SET СуммаРостаВППредГод,"Num($(СуммаВПТыс)-$(ВППредГод),'# ##0,00')",,
SET СуммаРостаВППредГод.Comment,Сумма роста Валовой Прибыли к предыдущему году,,
SET СуммаРостаВППредГод.Label,Сумма роста Валовой Прибыли к пред году,,
SET ВППредГод2,"Num((sum({<ТипДокумента = {2}, _ФлагДействующаяДата={1},ТипПериода={'Год-2'}>}ВП)/1000),'# ##0,00')",,
SET ВППредГод2.Comment,Валовая Прибыль за вычетом себестоимости и НДС за предпредыдущий год тыс.руб.,,
SET ВППредГод2.Label,Валовая Прибыль тыс.руб. предпред год,,
SET ПроцентВППредГод2,"Num($(СуммаВПТыс)/$(ВППредГод2),'# ##0,00%')",,
SET ПроцентВППредГод2.Comment,Процент Валовой Прибыли к предпредыдущему году,,
SET ПроцентВППредГод2.Label,% Валовой Прибыли к предпред году,,
SET СуммаРостаВППредГод2,"Num($(СуммаВПТыс)-$(ВППредГод2),'# ##0,00')",,
SET СуммаРостаВППредГод2.Comment,Сумма роста Валовой Прибыли к предпредыдущему году,,
SET СуммаРостаВППредГод2.Label,Сумма роста Валовой Прибыли к предпред году,,
SET ВППредМес,"Num((sum({<ТипДокумента = {2}, _ФлагДействующаяДата={1},ТипПериода={'ГодМесяц'}>}ВП)/1000),'# ##0,00')",,
SET ВППредМес.Comment,Валовая Прибыль за вычетом себестоимости и НДС за предыдущий месяц тыс.руб.,,
SET ВППредМес.Label,Валовая Прибыль тыс.руб. пред месяц,,
SET ПроцентВППредМес,"Num($(СуммаВПТыс)/$(ВППредМес),'# ##0,00%')",,
SET ПроцентВППредМес.Comment,Процент Валовой Прибыли к предыдущему месяцу,,
SET ПроцентВППредМес.Label,% Валовой Прибыли к пред месяцу,,
SET СуммаРостаВПМес,"Num($(СуммаВПТыс)-$(ВППредМес),'# ##0,00')",,
SET СуммаРостаВПМес.Comment,Сумма роста Валовой Прибыли к предыдущему месяцу,,
SET СуммаРостаВПМес.Label,Сумма роста Валовой Прибыли к пред месяцу,,
SET ПрцРентВП,"Num(($(СуммаВП)/$(СуммаПродажи)),'# ##0,00%')",,
SET ПрцРентВП.Comment,% Валовой прибыли,,
SET ПрцРентВП.Label,% Валовой Прибыли,,
SET ПланРентВП,"Num(($(ПланВП)/$(ПланПродаж)),'# ##0,00%')",,
SET ПланРентВП.Comment,План по %  Валовой прибыли,,
SET ПланРентВП.Label,План по % Валовой Прибыли,,
SET ПланРентВППолный,"Num(($(ПланВППолный)/$(ПланПродажПолный)),'# ##0,00%')",,
SET ПланРентВППолный.Comment,План по % Валовой прибыли полный месяц,,
SET ПланРентВППолный.Label,План по % Валовой Прибыли полный месяц,,
SET ПФРентВП,"Num(($(ПрцРентВП)/$(ПланРентВП)),'# ##0,00%')",,
SET ПФРентВП.Comment,ПФ % Валовой прибыли,,
SET ПФРентВП.Label,ПФ % Валовой Прибыли,,
SET П_Ф_РентВП,"Num(($(ПланРентВП)-$(ПрцРентВП)),'# ##0,00%')",,
SET П_Ф_РентВП.Comment,П-Ф % Валовой прибыли,,
SET П_Ф_РентВП.Label,П-Ф % Валовой Прибыли,,
SET РентВППредГод,"Num(($(ВППредГод)/$(ПродажиПредГод)),'# ##0,00%')",,
SET РентВППредГод.Comment,% Валовой Прибыли за предыдущий год,,
SET РентВППредГод.Label,% Валовой Прибыли пред год,,
SET ПроцентРентВППредГод,"Num($(ПрцРентВП)/$(РентВППредГод),'# ##0,00%')",,
SET ПроцентРентВППредГод.Comment,Процент Валовой Прибыли к предыдущему году,,
SET ПроцентРентВППредГод.Label,% изм. % Валовой Прибыли к пред году,,
SET СуммаРостаРентВППредГод,"Num($(ПрцРентВП)-$(РентВППредГод),'# ##0,00%')",,
SET СуммаРостаРентВППредГод.Comment,сумма изм % Валовой Прибыли к предыдущему году,,
SET СуммаРостаРентВППредГод.Label,сумма изм % Валовой Прибыли к пред году,,
SET РентВППредГод2,"Num(($(ВППредГод2)/$(ПродажиПредГод2)),'# ##0,00%')",,
SET РентВППредГод2.Comment,% Валовой Прибыли за предпредыдущий год,,
SET РентВППредГод2.Label,% Валовой Прибыли предпред год,,
SET ПроцентРентВППредГод2,"Num($(ПрцРентВП)/$(РентВППредГод2),'# ##0,00%')",,
SET ПроцентРентВППредГод2.Comment,Процент  изм. % Валовой Прибыли к предыдущему году,,
SET ПроцентРентВППредГод2.Label,% изм. % Валовой Прибыли к предпред году,,
SET СуммаРостаРентВППредГод2,"Num($(ПрцРентВП)-$(РентВППредГод2),'# ##0,00%')",,
SET СуммаРостаРентВППредГод2.Comment,сумма изм. % Валовой Прибыли к предпредыдущему году,,
SET СуммаРостаРентВППредГод2.Label,сумма изм. % Валовой Прибыил к предпред году,,
SET РентВППредМес,"Num(($(ВППредМес)/$(ПродажиПредМес)),'# ##0,00%')",,
SET РентВППредМес.Comment,% Валовой Прибыли за предпредыдущий месяц,,
SET РентВППредМес.Label,% Валовой Прибыли пред месяц,,
SET ПроцентРентВППредМес,"Num($(ПрцРентВП)/$(РентВППредМес),'# ##0,00%')",,
SET ПроцентРентВППредМес.Comment,Процент  изм. % Валовой Прибыли к предыдущему месяцу,,
SET ПроцентРентВППредМес.Label,% изм. % Валовой Прибыли к пред. месяцу,,
SET СуммаРостаРентВППредМес,"Num($(ПрцРентВП)-$(РентВППредМес),'# ##0,00%')",,
SET СуммаРостаРентВППредМес.Comment,сумма изм. % Валовой Прибыли к предпредыдущему месяцу,,
SET СуммаРостаРентВППредМес.Label,сумма изм. % Валовой Прибыли к пред месяцу,,
SET ОстаткиКоличество,"Money(Sum({<ТипДокумента={11},_МесяцПоПорядку={'$(=Max({<_ФлагДействующаяДата={1}>} _МесяцПоПорядку))'}, _ДеньПоПорядку={'$(=Max({<_ФлагДействующаяДата={1}>} _ДеньПоПорядку))'},$(СбросФильтраПоОстаткам),ТипПериода={'Current'}>} Количество),'# ##0,00')",,
SET ОстаткиКоличество.Comment,Остатки количество на конец выбранного периода,,
SET ОстаткиКоличество.Label,Остатки Количество на конец периода,,
SET ОстаткиКоличествоСреднее,"(Sum({$<ТипДокумента = {10},$(СбросФильтраПоОстаткам),ТипПериода={'Current'}>} Количество) / $(КоличествоДней))",,
SET ОстаткиКоличествоСреднее.Comment,Остатки  среднее количество,,
SET ОстаткиКоличествоСреднее.Label,Остатки средние,,
SET ОстатокШтукНаКонецПериода_Формула,"Sum({<ТипПериода={'Current'},ТипДокумента={11},$(СбросФильтраПоОстаткам),Дата={""$(=Max({<$(СбросФильтраПоОстаткам),_ФлагДействующаяДата={1}>} Дата))""}>} Количество)",,
SET ОстатокШтукНаКонецПериода,"Money($(ОстатокШтукНаКонецПериода_Формула),'# ##0,00')",,
SET ОстатокШтукНаКонецПериода.Comment,Складские остатки в штуках на конец периода,,
SET ОстатокШтукНаКонецПериода.Label,"Остаток на конец периода, шт",,
SET ОстатокШтукНаКонецДня_Формула,"(Sum({<$(СбросФильтраПоОстаткам),_ФлагДействующаяДата={1},ТипПериода={'OnHand_Sum'},ТипДокумента={9}>} Количество) + Sum({<$(СбросФильтраПоОстаткам),_ФлагДействующаяДата={1},ТипПериода={'OnHand_Eom'},ТипДокумента={11}>} Количество))",,
SET ОстатокШтукНаКонецДня,"Money($(ОстатокШтукНаКонецДня_Формула),'# ##0,00')",,
SET ОстатокШтукНаКонецДня.Comment,Складские остатки в штуках на конец дня,,
SET ОстатокШтукНаКонецДня.Label,"Остаток на конец периода, шт",,
SET ОстатокСебестоимостьНаКонецДня_Формула,"(Sum({<$(СбросФильтраПоОстаткам),ТипПериода={'OnHand_Sum'},ТипДокумента={9}>} Себестоимость) + Sum({<$(СбросФильтраПоОстаткам),ТипПериода={'OnHand_Eom'},ТипДокумента={11}>} Себестоимость))",,
SET ОстатокСебестоимостьНаКонецДня,"Money($(ОстатокСебестоимостьНаКонецДня_Формула),'# ##0,00')",,
SET ОстатокСебестоимостьНаКонецДня.Comment,Себестоимость складских остатков на конец дня,,
SET ОстатокСебестоимостьНаКонецДня.Label,"Себестоимость остатков на конец дня, шт",,
SET ПродажиСуммаСреднедневные,"Money(($(СуммаПродажи) / Count({<_ФлагДействующаяДата={1}>} TOTAL DISTINCT Дата)),'# ##0,00')",,
SET ПродажиСуммаСреднедневные.Comment,Среднедневная сумма продаж за выбранный период,,
SET ПродажиСуммаСреднедневные.Label,"Среденедневная покупка, руб",,
SET ПродажиКоличествоСреднедневные,"Money(($(ПродажиКоличество) / Count({<_ФлагДействующаяДата={1}>} TOTAL DISTINCT Дата)),'# ##0,00')",,
SET ПродажиКоличествоСреднедневные.Comment,Среднедневное количество проданного товара за выбранный период,,
SET ПродажиКоличествоСреднедневные.Label,"Среднедневная покупка, за выбранный период шт/кг",,
SET T30,"Money(Sum({$<ТипДокумента ={2},ТипПериода={'Current'}, Дата={'>=$(=Date(Max({<_ФлагДействующаяДата={1}>} Дата)-29))<=$(=Date(Max({<_ФлагДействующаяДата={1}>} Дата)))'}>} Количество)/30,'# ##0,00')",,
SET T30.Comment,"Среднедневная покупка, за последние 30 дней от конечной даты выбранного периода шт/кг",,
SET T30.Label,"Среднедневная покупка, за последние 30 дней шт/кг",,
SET ЗапасыВДняхНаКонецПериода," Money(if(($(ПродажиКоличество))=0 and ($(ОстатокШтукНаКонецПериода_Формула))>0,30000, if(($(ОстатокШтукНаКонецПериода_Формула))<>0 and ($(ПродажиКоличество))<0,0, if(($(ОстатокШтукНаКонецПериода_Формула))<=0 and ($(ПродажиКоличество))>0,0,($(ОстатокШтукНаКонецПериода_Формула))/($(T30))))),'# ##0,00')",,
SET ЗапасыВДняхНаКонецПериода.Comment,Запасы в днях на конец периода.,,
SET ЗапасыВДняхНаКонецПериода.Label,Запас в Днях,,
SET СбросФильтраПоОстаткам,"ВидДеятельности,КодКлиента,Клиент,ГруппаКлиента",,
SET ОстаткиСебестоимость,"Sum({<$(СбросФильтраПоОстаткам),ТипДокумента={11}, _ДеньПоПорядку={'$(=Max({<_ФлагДействующаяДата={1},_КонецНеделиМесяца={1}>} _ДеньПоПорядку))'}, ТипПериода={'Current'}>} Себестоимость)",,
SET ОстаткиСебестоимость.Comment,Остаток себестоимость на конец выбранного периода,,
SET ОстаткиСебестоимость.Label,"Остаток на конец периода, руб",,
SET ОстаткиСебестоимостьПоШкалеЛиквидности,"Money((Sum({$<ТипДокумента = {10},ТипПериода={'Current'},ВидДеятельности,КодКлиента,Клиент,ГруппаКлиента>} Себестоимость) / $(КоличествоДней))/1000,'# ##0,00')",,
SET ОстаткиСебестоимостьПоШкалеЛиквидности.Comment,Остатки средняя себестоимость по суммам,,
SET ОстаткиСебестоимостьПоШкалеЛиквидности.Label,Остатки средние,,
SET ОстаткиСебестоимостьТыс,"Money(($(ОстаткиСебестоимость)/1000),'# ##0,00')",,
SET ОстаткиСебестоимостьТыс.Comment,Остаток себестоимость на конец выбранного периода тыс. руб.,,
SET ОстаткиСебестоимостьТыс.Label,"Остаток на конец периода, тыс. руб",,
SET Остатки," Money(Sum({$<ТипДокумента = {10},ТипПериода={'Current'},$(СбросФильтраПоОстаткам)>} Себестоимость) / $(КоличествоДней),'# ##0,00')",,
SET Остатки.Comment,Остатки себестоимость среднедневная за выбранный период,,
SET Остатки.Label,Остатки средние,,
SET ОстаткиТысМесяц," Money($(Остатки)/1000,'# ##0,00')",,
SET ОстаткиТысМесяц.Comment,Остатки себестоимость среднедневная за выбранный период,,
SET ОстаткиТысМесяц.Label,Остатки средние,,
SET Остатки30," Money(Sum({$<ТипДокумента = {12},ТипПериода={'Current'},$(СбросФильтраПоОстаткам)>} Себестоимость) / 30,'# ##0,00')",,
SET Остатки30.Comment,Остатки себестоимость среднедневная за последние 30 дней,,
SET Остатки30.Label,Остатки средние 30 дней,,
SET ОстаткиТыс,"$($(=If(InMonth(Only(ГодМесяц),$(vU.CurrentDate),0),'Остатки30Тыс','ОстаткиТысМесяц')))",,
SET ОстаткиТыс.Comment,"=If (InMonth(Only(ГодМесяц),$(vU.CurrentDate),0),'Остатки себестоимость среднедневная за последние 30 дней','Остатки средняя себестоимость в тыс. руб.')",,
SET ОстаткиТыс.Label,"=If(InMonth(Only(ГодМесяц),$(vU.CurrentDate),0),'Остатки средние 30 дней тыс. руб.','Остатки средние тыс. руб.')",,
SET Остатки30Тыс," Num($(Остатки30)/1000,'# ##0,00')",,
SET Остатки30Тыс.Comment,Остатки средняя себестоимость в тыс. руб. за последние 30 дней,,
SET Остатки30Тыс.Label,Остатки средние 30 дней в тыс. руб.,,
SET ПланОстатки,"Num(Sum({$<ТипДокумента = {13},ТипПериода={'Current'}>} Себестоимость) / $(КоличествоДнейВключаяБудущийПериод),'# ##0,00')",,
SET ПланОстатки.Comment,Плановые остатки средние (расчет),,
SET ПланОстатки.Label,План остатки,,
SET ПланОстаткиТыс,"Num((Sum({$<ТипДокумента = {13},ТипПериода={'Current'}>} Себестоимость) / $(КоличествоДнейВключаяБудущийПериод))/1000,'# ##0,00')",,
SET ПланОстаткиТыс.Comment,"Плановые остатки средние (расчет) , тыс. руб.",,
SET ПланОстаткиТыс.Label,"План остатки , тыс. руб.",,
SET ПФ_Остатки,"Num($(ОстаткиТыс)/$(ПланОстаткиТыс),'# ##0,0%')",,
SET ПФ_Остатки.Comment,Факт отнесенный к плану по остаткам,,
SET ПФ_Остатки.Label,ПФ Остатки,,
SET П_Ф_Остатки,"Num( (-$(ПланОстатки)+($(ОстаткиТыс)/1000)),'# ##0,00')",,
SET П_Ф_Остатки.Comment,План минус  факт по остаткам,,
SET П_Ф_Остатки.Label,П-Ф Остатки,,
SET П_Ф_ОстаткиТыс,"Num(($(П_Ф_Остатки))/1000,'# ##0,00')",,
SET П_Ф_ОстаткиТыс.Comment,План минус  факт по остаткам,,
SET П_Ф_ОстаткиТыс.Label,П-Ф Остатков тыс. руб.,,
SET ОстаткиПредГодОбщие,"Num((Sum({<ТипДокумента = {10},ТипПериода={'КонецМесяцаГод'},$(СбросФильтраПоОстаткам)>} Себестоимость)/1000),'# ##0,00')",,
SET ОстаткиПредГодОбщие.Comment,Остатки себестоимость по суммам за предыдущий год,,
SET ОстаткиПредГодОбщие.Label,Остатки пред год,,
SET ОстаткиПредГод,"Num((Sum({<ТипДокумента = {10},ТипПериода={'КонецМесяцаГод'},$(СбросФильтраПоОстаткам)>} Себестоимость)/1000) / Sum({<_КонецМесяца={1},ТипПериода={'КонецМесяцаГод'}>} _ДнейПрошлогоПериодаВМесяце),'# ##0,00')",,
SET ОстаткиПредГод.Comment,Остатки  средняя себестоимость по суммам за предыдущий год,,
SET ОстаткиПредГод.Label,Остатки средние пред год,,
SET ПроцентОстаткиПредГод,"Num(($(ОстаткиТыс))/($(ОстаткиПредГод)),'# ##0,00%')",,
SET ПроцентОстаткиПредГод.Comment,Процент Остатков к предыдущему году,,
SET ПроцентОстаткиПредГод.Label,% Остатков к пред году,,
SET СуммаРостаОстаткиПредГод,"Num(($(ОстаткиТыс))-($(ОстаткиПредГод)),'# ##0,00')",,
SET СуммаРостаОстаткиПредГод.Comment,СуммаРоста Остатков к предыдущему году,,
SET СуммаРостаОстаткиПредГод.Label,СуммаРостаОстатков к пред году,,
SET ОстаткиПредГод2Общие,"Num((Sum({<ТипДокумента = {10},ТипПериода={'КонецМесяцаГод2'},$(СбросФильтраПоОстаткам)>} Себестоимость)/1000),'# ##0,00')",,
SET ОстаткиПредГод2Общие.Comment,Остатки себестоимость по суммам за предпредыдущий год,,
SET ОстаткиПредГод2Общие.Label,Остатки предпред год,,
SET ОстаткиПредГод2,"Num(((Sum({<ТипДокумента = {10},ТипПериода={'КонецМесяцаГод2'},$(СбросФильтраПоОстаткам)>} Себестоимость)/1000) / Sum({<_КонецМесяца={1},ТипПериода={'КонецМесяцаГод2'}>} _ДнейПрошлогоПериодаВМесяце)),'# ##0,00')",,
SET ОстаткиПредГод2.Comment,Остатки  средняя себестоимость по суммам за предпредыдущий год,,
SET ОстаткиПредГод2.Label,Остатки средние предпред год,,
SET ПроцентОстаткиПредГод2,"Num(($(ОстаткиТыс))/($(ОстаткиПредГод2)),'# ##0,00%')",,
SET ПроцентОстаткиПредГод2.Comment,Процент Остатков к предпредыдущему го,,
SET ПроцентОстаткиПредГод2.Label,% Остатков к предпред году,,
SET СуммаРостаОстаткиПредГод2,"Num(($(ОстаткиТыс))-($(ОстаткиПредГод2)),'# ##0,00')",,
SET СуммаРостаОстаткиПредГод2.Comment,СуммаРоста Остатков к предпредыдущему году,,
SET СуммаРостаОстаткиПредГод2.Label,СуммаРоста Остатков к предпред году,,
SET ОстаткиПредМесОбщие,"Num((Sum({<ТипДокумента = {10},ТипПериода={'ГодМесяц'},$(СбросФильтраПоОстаткам)>} Себестоимость)/1000),'# ##0,00')",,
SET ОстаткиПредМесОбщие.Comment,Остатки себестоимость по суммам за предыдущий месяц,,
SET ОстаткиПредМесОбщие.Label,Остатки пред  месяц,,
SET ОстаткиПредМес,"Num(((Sum({<ТипДокумента = {10},ТипПериода={'ГодМесяц'},$(СбросФильтраПоОстаткам)>} Себестоимость)/1000) / Sum({<_КонецМесяца={1},ТипПериода={'КонецМесяца'}>} _ДнейПрошлогоПериодаВМесяце)),'# ##0,00')",,
SET ОстаткиПредМес.Comment,Остатки  средняя себестоимость по суммам за предыдущий месяц,,
SET ОстаткиПредМес.Label,Остатки средние пред  месяц,,
SET ПроцентОстаткиПредМес,"Num(($(ОстаткиТыс))/($(ОстаткиПредМес)),'# ##0,00%')",,
SET ПроцентОстаткиПредМес.Comment,Процент Остатков к предыдущему месяцу,,
SET ПроцентОстаткиПредМес.Label,% Остатков к пред месяцу,,
SET СуммаРостаОстаткиПредМес,"Num(($(ОстаткиТыс))-($(ОстаткиПредМес)),'# ##0,00')",,
SET СуммаРостаОстаткиПредМес.Comment,СуммаРоста Остатков к предыдущему месяцу,,
SET СуммаРостаОстаткиПредМес.Label,СуммаРоста Остатков к пред месяцу,,
SET УчСебестоимостьПолный,"Num((sum({<ТипДокумента = {2},ТипПериода={'Current'}>}Себестоимость)),'# ##0,0')",,
SET УчСебестоимостьПолный.Comment,Учетная себестоимость,,
SET УчСебестоимостьПолный.Label,Себестоимость,,
SET УчСебестоимостьПолныйПредГод,"Num((sum({<ТипДокумента = {2},ТипПериода={'Год'}>}Себестоимость)/1000),'# ##0,0')",,
SET УчСебестоимостьПолныйПредГод.Comment,Учетная себестоимость за предыдущий год,,
SET УчСебестоимостьПолныйПредГод.Label,Себестоимость пред год,,
SET УчСебестоимостьПолныйПредГод2,"Num((sum({<ТипДокумента = {2},ТипПериода={'Год-2'}>}Себестоимость)/1000),'# ##0,0')",,
SET УчСебестоимостьПолныйПредГод2.Comment,Учетная себестоимость за предыдущий год,,
SET УчСебестоимостьПолныйПредГод2.Label,Себестоимость пред год,,
SET УчСебестоимостьПолныйПредМесяц,"Num((sum({<ТипДокумента = {2},ТипПериода={'ГодМесяц'}>}Себестоимость)/1000),'# ##0,0')",,
SET УчСебестоимостьПолныйПредМесяц.Comment,Учетная себестоимость за предыдущий месяц,,
SET УчСебестоимостьПолныйПредМесяц.Label,Себестоимость пред месяц,,
SET СбросФильтраПоПланам,"КодНоменклатуры,Номенклатура,Уровень4,Уровень3,ШкалаЛиквидности",,
SET ОборачиваемостьМесяц,"Num((Sum({$<ТипДокумента = {10},$(СбросФильтраПоОстаткам),ТипПериода={'Current'}>} Себестоимость) / ($(УчСебестоимостьПолный))),'# ##0,0')",,
SET ОборачиваемостьМесяц.Comment,Оборачиваемость (считается только вплоть до месяцов),,
SET ОборачиваемостьМесяц.Label,Оборачиваемость,,
SET Оборачиваемость30,"Money(Sum({$<ТипДокумента = {12},ТипПериода={'Current'},$(СбросФильтраПоОстаткам)>} Себестоимость) / Sum({$<ТипДокумента = {12},ТипПериода={'Current'},$(СбросФильтраПоОстаткам)>} СебестоимостьБезНДС),'# ##0,00')",,
SET Оборачиваемость30.Comment,Оборачиваемость товаров за последние 30 дней,,
SET Оборачиваемость30.Label,Оборачиваемость за 30 дней,,
SET Оборачиваемость,"$($(=If(InMonth(Only(ГодМесяц),$(vU.CurrentDate),0),'Оборачиваемость30','ОборачиваемостьМесяц')))",,
SET Оборачиваемость.Comment,"=If(InMonth(Only(ГодМесяц),$(vU.CurrentDate),0),'Оборачиваемость товаров за последние 30 дней','Оборачиваемость (считается только вплоть до месяцов)')",,
SET Оборачиваемость.Label,"=If(InMonth(Only(ГодМесяц),$(vU.CurrentDate),0),'Оборачиваемость за 30 дней','Оборачиваемость')",,
SET ПланОборачиваемость,"Money((Sum({$<ТипДокумента = {13},ТипПериода={'Current'}>} Себестоимость) / ($(ПланПродаж) - $(ПланВП))),'# ##0,0')",,
SET ПланОборачиваемость.Comment,План по оборачиваемости,,
SET ПланОборачиваемость.Label,План оборачиваемость,,
SET ПланОборачиваемость2,"Money(Sum({$<ТипДокумента = {13},ТипПериода={'Current'}, $(СбросФильтраПоПланам)>} Себестоимость)/ (Sum({<_ФлагДействующаяДата={1},ТипДокумента={13},ТипПериода={'Current'}, $(СбросФильтраПоПланам)>} Сумма) - Sum({<_ФлагДействующаяДата={1},ТипДокумента={13},ТипПериода={'Current'}, $(СбросФильтраПоПланам)>} ВП)),'# ##0,0')",,
SET ПланОборачиваемость2.Comment,План по оборачиваемости,,
SET ПланОборачиваемость2.Label,План оборачиваемость2,,
SET НормаОборачиваемость,"Money(Avg({$<ТипДокумента = {21},$(СбросФильтраПоОстаткам),ШкалаЛиквидности,ТипПериода={'Current'}>} Количество),'# ##0,0')",,
SET НормаОборачиваемость.Comment,Норматив оборачиваемости по третьему уровню классификатора,,
SET НормаОборачиваемость.Label,Норматив оборачиваемости,,
SET ПФ_Оборачиваемость,"Num(($(Оборачиваемость)/$(ПланОборачиваемость)),'# ##0,00%')",,
SET ПФ_Оборачиваемость.Comment,ПФ Оборачиваемость,,
SET ПФ_Оборачиваемость.Label,ПФ Оборачиваемость,,
SET П_Ф_Оборачиваемость,"Num((-$(ПланОборачиваемость)+$(Оборачиваемость)),'# ##0,00')",,
SET П_Ф_Оборачиваемость.Comment,План минус  факт по оборачиваемости,,
SET П_Ф_Оборачиваемость.Label,П-Ф Оборачиваемость,,
SET ОборачиваемостьПредГод,"Num((($(ОстаткиПредГодОбщие))/($(УчСебестоимостьПолныйПредГод))),'# ##0,0')",,
SET ОборачиваемостьПредГод.Comment,Оборачиваемость за предыдущий год,,
SET ОборачиваемостьПредГод.Label,Оборачиваемость пред год,,
SET ПроцентОборачиваемостьПредГод,"Num($(Оборачиваемость)/$(ОборачиваемостьПредГод),'# ##0,00%')",,
SET ПроцентОборачиваемостьПредГод.Comment,Процент Оборачиваемости к предыдущему году,,
SET ПроцентОборачиваемостьПредГод.Label,% Оборачиваемости к пред году,,
SET СуммаРостаОборачиваемостьПредГод,"Num($(Оборачиваемость)-$(ОборачиваемостьПредГод),'# ##0,0')",,
SET СуммаРостаОборачиваемостьПредГод.Comment,СуммаРоста Оборачиваемости к предыдущему году,,
SET СуммаРостаОборачиваемостьПредГод.Label,СуммаРоста Оборачиваемости к пред году,,
SET ОборачиваемостьПредГод2,"Num((($(ОстаткиПредГод2Общие))/($(УчСебестоимостьПолныйПредГод2))),'# ##0,0')",,
SET ОборачиваемостьПредГод2.Comment,Оборачиваемость за предпредыдущий год,,
SET ОборачиваемостьПредГод2.Label,Оборачиваемость предпред год,,
SET ПроцентОборачиваемостьПредГод2,"Num($(Оборачиваемость)/$(ОборачиваемостьПредГод2),'# ##0,00%')",,
SET ПроцентОборачиваемостьПредГод2.Comment,Процент Оборачиваемости к предыдущему году,,
SET ПроцентОборачиваемостьПредГод2.Label,% Оборачиваемости к предпред году,,
SET СуммаРостаОборачиваемостьПредГод2,"Num($(Оборачиваемость)-$(ОборачиваемостьПредГод2),'# ##0,0')",,
SET СуммаРостаОборачиваемостьПредГод2.Comment,СуммаРоста Оборачиваемости к предыдущему году,,
SET СуммаРостаОборачиваемостьПредГод2.Label,СуммаРоста Оборачиваемости к предпред году,,
SET ОборачиваемостьПредМес,"Num((($(ОстаткиПредМесОбщие))/($(УчСебестоимостьПолныйПредМесяц))),'# ##0,0')",,
SET ОборачиваемостьПредМес.Comment,Оборачиваемость за предпредыдущий месяц,,
SET ОборачиваемостьПредМес.Label,Оборачиваемость пред  мес,,
SET ПроцентОборачиваемостьПредМес,"Num($(Оборачиваемость)/$(ОборачиваемостьПредМес),'# ##0,00%')",,
SET ПроцентОборачиваемостьПредМес.Comment,Процент Оборачиваемости к предыдущему месяц,,
SET ПроцентОборачиваемостьПредМес.Label,% Оборачиваемости к пред мес,,
SET СуммаРостаОборачиваемостьПредМес,"Num($(Оборачиваемость)-$(ОборачиваемостьПредМес),'# ##0,0')",,
SET СуммаРостаОборачиваемостьПредМес.Comment,СуммаРоста Оборачиваемости к предыдущему месяц,,
SET СуммаРостаОборачиваемостьПредМес.Label,СуммаРоста Оборачиваемости к пред мес,,
SET СуммаСкидки,"Num((Sum({$<ТипДокумента={2},ТипПериода={'Current'}>}Скидка)),'# ##0,00')",,
SET СуммаСкидки.Comment,Сумма предоставленной скидки в руб.,,
SET СуммаСкидки.Label,СуммаСкидки руб.,,
SET СуммаСкидкиТыс,"Num((Sum({$<ТипДокумента={2},ТипПериода={'Current'}>}Скидка)/1000),'# ##0,00')",,
SET СуммаСкидкиТыс.Comment,Сумма предоставленной скидки в тыс. руб.,,
SET СуммаСкидкиТыс.Label,СуммаСкидки тыс. руб.,,
SET СуммаСкидкиТысПредГод,"Num((Sum({$<ТипДокумента={2},_ФлагДействующаяДата={1},ТипПериода={'Год'}>}Скидка)/1000),'# ##0,00')",,
SET СуммаСкидкиТысПредГод.Comment,Сумма предоставленной скидки за пред год в тыс. руб.,,
SET СуммаСкидкиТысПредГод.Label,СуммаСкидки тыс. руб. пред год,,
SET ПроцентСуммаСкидкиТысПредГод,"Num($(СуммаСкидкиТыс)/$(СуммаСкидкиТысПредГод),'# ##0,00%')",,
SET ПроцентСуммаСкидкиТысПредГод.Comment,Процент Суммы скидки к предыдущему году,,
SET ПроцентСуммаСкидкиТысПредГод.Label,% Суммы скидки к пред году,,
SET СуммаРостаСуммаСкидкиТысПредГод,"Num($(СуммаСкидкиТыс)-$(СуммаСкидкиТысПредГод),'# ##0,00')",,
SET СуммаРостаСуммаСкидкиТысПредГод.Comment,Изменение Суммы скидки к предыдущему году,,
SET СуммаРостаСуммаСкидкиТысПредГод.Label,Изменение суммы скидки к пред году,,
SET СуммаСкидкиТысПредГод2,"Num((Sum({$<ТипДокумента={2},_ФлагДействующаяДата={1},ТипПериода={'Год-2'}>}Скидка)/1000),'# ##0,00')",,
SET СуммаСкидкиТысПредГод2.Comment,Сумма предоставленной скидки за предпред год в тыс. руб.,,
SET СуммаСкидкиТысПредГод2.Label,СуммаСкидки тыс. руб. предпред год,,
SET ПроцентСуммаСкидкиТысПредГод2,"Num($(СуммаСкидкиТыс)/$(СуммаСкидкиТысПредГод2),'# ##0,00%')",,
SET ПроцентСуммаСкидкиТысПредГод2.Comment,Процент Суммы скидки к пердпредыдущему году,,
SET ПроцентСуммаСкидкиТысПредГод2.Label,% Суммы скидки к предпред году,,
SET СуммаРостаСуммаСкидкиТысПредГод2,"Num($(СуммаСкидкиТыс)-$(СуммаСкидкиТысПредГод2),'# ##0,00')",,
SET СуммаРостаСуммаСкидкиТысПредГод2.Comment,Изменение Суммы скидки к предпредыдущему году,,
SET СуммаРостаСуммаСкидкиТысПредГод2.Label,Изменение Суммы скидки к предпред году,,
SET СуммаСкидкиТысПредМес,"Num((Sum({$<ТипДокумента={2},_ФлагДействующаяДата={1},ТипПериода={'ГодМесяц'}>}Скидка)/1000),'# ##0,00')",,
SET СуммаСкидкиТысПредМес.Comment,Сумма предоставленной скидки за предыдущий месяц в тыс. руб.,,
SET СуммаСкидкиТысПредМес.Label,СуммаСкидки тыс. руб. пред мес,,
SET ПроцентСуммаСкидкиТысПредМес,"Num($(СуммаСкидкиТыс)/$(СуммаСкидкиТысПредМес),'# ##0,00%')",,
SET ПроцентСуммаСкидкиТысПредМес.Comment,Процент Суммы скидки к предыдущему месяцу,,
SET ПроцентСуммаСкидкиТысПредМес.Label,% Суммы скидки к пред мес,,
SET СуммаРостаСуммаСкидкиТысПредМес,"Num($(СуммаСкидкиТыс)-$(СуммаСкидкиТысПредМес),'# ##0,00')",,
SET СуммаРостаСуммаСкидкиТысПредМес.Comment,Изменение Суммы скидки к предыдущему месяцу,,
SET СуммаРостаСуммаСкидкиТысПредМес.Label,Изменение Суммы скидки к пред мес,,
SET ПроцентСкидки,"Num(alt($(СуммаСкидки)/($(СуммаПродажи)+$(СуммаСкидки)),0),'# ##0,00%')",,
SET ПроцентСкидки.Comment,Процент предоставленной скидки,,
SET ПроцентСкидки.Label,ПроцентСкидки,,
SET ПроцентСкидкиПредГод,"Num(alt($(СуммаСкидкиТысПредГод)/($(ПродажиПредГод)+$(СуммаСкидкиТысПредГод)),0),'# ##0,00%')",,
SET ПроцентСкидкиПредГод.Comment,Процент предоставленной скидки за пред год,,
SET ПроцентСкидкиПредГод.Label,ПроцентСкидки пред год,,
SET ПроцентПроцентСкидкиПредГод,"Num($(ПроцентСкидки)/$(ПроцентСкидкиПредГод),'# ##0,00%')",,
SET ПроцентПроцентСкидкиПредГод.Comment,Процент от Процента скидки к предыдущему году,,
SET ПроцентПроцентСкидкиПредГод.Label,% Процента скидки к пред году,,
SET СуммаРостаСПроцентСкидкиПредГод,"Num($(ПроцентСкидки)-$(ПроцентСкидкиПредГод),'# ##0,00%')",,
SET СуммаРостаСПроцентСкидкиПредГод.Comment,Изменение от Процента скидки к предыдущему году тот же день недели,,
SET СуммаРостаСПроцентСкидкиПредГод.Label,Изменение процента скидки к пред году тот же день недели,,
SET ПроцентСкидкиПредГод2,"Num(alt($(СуммаСкидкиТысПредГод2)/($(ПродажиПредГод2)+$(СуммаСкидкиТысПредГод2)),0),'# ##0,00%')",,
SET ПроцентСкидкиПредГод2.Comment,Процент предоставленной скидки за предпред год,,
SET ПроцентСкидкиПредГод2.Label,ПроцентСкидки предпред год,,
SET ПроцентПроцентСкидкиПредГод2,"Num($(ПроцентСкидки)/$(ПроцентСкидкиПредГод2),'# ##0,00%')",,
SET ПроцентПроцентСкидкиПредГод2.Comment,Процент от Процента скидки к предпредыдущему году,,
SET ПроцентПроцентСкидкиПредГод2.Label,% Процента скидки к предпред году,,
SET СуммаРостаСПроцентСкидкиПредГод2,"Num($(ПроцентСкидки)-$(ПроцентСкидкиПредГод2),'# ##0,00%')",,
SET СуммаРостаСПроцентСкидкиПредГод2.Comment,Изменение от Процента скидки к предпредыдущему году тот же день недели,,
SET СуммаРостаСПроцентСкидкиПредГод2.Label,Изменение процента скидки к предпред году тот же день недели,,
SET ПроцентСкидкиПредМес,"Num(alt($(СуммаСкидкиТысПредМес)/($(ПродажиПредМес)+$(СуммаСкидкиТысПредМес)),0),'# ##0,00%')",,
SET ПроцентСкидкиПредМес.Comment,Процент предоставленной скидки  предыдущего месяца,,
SET ПроцентСкидкиПредМес.Label,ПроцентСкидки пред мес,,
SET ПроцентПроцентСкидкиПредМес,"Num($(ПроцентСкидки)/$(ПроцентСкидкиПредМес),'# ##0,00%')",,
SET ПроцентПроцентСкидкиПредМес.Comment,Процент от Процента скидки к предыдущему месяцу,,
SET ПроцентПроцентСкидкиПредМес.Label,% Процента скидки к пред мес,,
SET СуммаРостаСПроцентСкидкиПредМес,"Num($(ПроцентСкидки)-$(ПроцентСкидкиПредМес),'# ##0,00%')",,
SET СуммаРостаСПроцентСкидкиПредМес.Comment,Изменение от Процента скидки к предыдущему месяцу,,
SET СуммаРостаСПроцентСкидкиПредМес.Label,Изменение процента скидки к пред мес,,
SET ВыбранныеПоляКалендаря1,"=if(GetSelectedCount(Дата)>0, ',Дата={""' & GetFieldSelections(Дата,'"",""',1000) &'""}', '') & if(GetSelectedCount(Год)>0, ',Год={""' & GetFieldSelections(Год,'"",""',1000) &'""}', '') & if(GetSelectedCount(Месяц)>0, ',Месяц={""' & GetFieldSelections(Месяц,'"",""',1000) &'""}', '')",,
SET ГрупповоеВыражение_ФорматТыс,"If(IsNull(Only({<ГП_$1={$2}>}  _ГП_$1_ФорматТыс)),'млн','тыс')",,
SET ГрупповоеВыражение_ФорматМлн,"If(IsNull(Only({<ГП_$1={$2}>}  _ГП_$1_ФорматМлн)),'мрд','млн')",,
SET ГрупповоеВыражение_ФорматМрд,"If(IsNull(Only({<ГП_$1={$2}>}  _ГП_$1_ФорматМлрд)),'трн','мрд')",,
SET ПоказатьОстаткиПоМесяцам,(only(_Группа$1)='Дата'  or only(_Группа$1)='Неделя' or only(_Группа$1)='Посл 8 Дней') and (only(_ГруппаПоказателей_$2)='Остатки' or only(_ГруппаПоказателей_$2)='Оборачиваемость'),,
SET СтрелкаТренда,"if ($1 = 0 OR IsNull($1), null(), 'qmem://<builtin>/' & if($1 >= 1.20,'Arrow_N_G.png', if($1 >= 1.051,'Arrow_NE_G.png', if($1 >= 1.05 ,'Arrow_NE_G.png', if($1 >= 1,'Arrow_E_Y.png', if($1 >= .95 ,'Arrow_W_Y.png', if($1 >= .801  ,'Arrow_SE_R.png', if($1 >= .80 ,'Arrow_S_R.png', if($1 >= 0 ,'Arrow_S_R.png','Arrow_S_R.png') ))))))))",,
SET ТрендПродажиПредГод,"if ($(ПроцентПродажиПредГод) = 0 OR IsNull($(ПроцентПродажиПредГод)), null(), 'qmem://<builtin>/' & if($(ПроцентПродажиПредГод) >= 1.20,'Arrow_N_G.png', if($(ПроцентПродажиПредГод) >= 1.051,'Arrow_NE_G.png', if($(ПроцентПродажиПредГод) >= 1.05 ,'Arrow_NE_G.png', if($(ПроцентПродажиПредГод) >= 1,'Arrow_E_Y.png', if($(ПроцентПродажиПредГод) >= .95 ,'Arrow_W_Y.png', if($(ПроцентПродажиПредГод) >= .801  ,'Arrow_SE_R.png', if($(ПроцентПродажиПредГод) >= .80 ,'Arrow_S_R.png', if($(ПроцентПродажиПредГод) >= 0 ,'Arrow_S_R.png','Arrow_S_R.png') ))))))))",,
SET ТрендПродажиПредГод.Comment,Тренд продаж к предыдущему году,,
SET ТрендВППредГод,"if ($(ПроцентВППредГод) = 0 OR IsNull($(ПроцентВППредГод)), null(), 'qmem://<builtin>/' & if($(ПроцентВППредГод) >= 1.20,'Arrow_N_G.png', if($(ПроцентВППредГод) >= 1.051,'Arrow_NE_G.png', if($(ПроцентВППредГод) >= 1.05 ,'Arrow_NE_G.png', if($(ПроцентВППредГод) >= 1,'Arrow_E_Y.png', if($(ПроцентВППредГод) >= .95 ,'Arrow_W_Y.png', if($(ПроцентВППредГод) >= .801  ,'Arrow_SE_R.png', if($(ПроцентВППредГод) >= .80 ,'Arrow_S_R.png', if($(ПроцентВППредГод) >= 0 ,'Arrow_S_R.png','Arrow_S_R.png') ))))))))",,
SET ТрендВППредГод.Comment,Тренд ВП к предыдущему году,,
SET ТрендРентВППредГод,"if ($(ПроцентРентВППредГод) = 0 OR IsNull($(ПроцентРентВППредГод)), null(), 'qmem://<builtin>/' & if($(ПроцентРентВППредГод) >= 1.20,'Arrow_N_G.png', if($(ПроцентРентВППредГод) >= 1.051,'Arrow_NE_G.png', if($(ПроцентРентВППредГод) >= 1.05 ,'Arrow_NE_G.png', if($(ПроцентРентВППредГод) >= 1,'Arrow_E_Y.png', if($(ПроцентРентВППредГод) >= .95 ,'Arrow_W_Y.png', if($(ПроцентРентВППредГод) >= .801  ,'Arrow_SE_R.png', if($(ПроцентРентВППредГод) >= .80 ,'Arrow_S_R.png', if($(ПроцентРентВППредГод) >= 0 ,'Arrow_S_R.png','Arrow_S_R.png') ))))))))",,
SET ТрендРентВППредГод.Comment,Тренд рентабельности ВП к предыдущему году,,
SET ТрендОборачиваемостьПредГод,"if ($(ПроцентОборачиваемостьПредГод) = 0 OR IsNull($(ПроцентОборачиваемостьПредГод)), null(), 'qmem://<builtin>/' & if($(ПроцентОборачиваемостьПредГод) >= 1.20,'Arrow_N_G.png', if($(ПроцентОборачиваемостьПредГод) >= 1.051,'Arrow_NE_G.png', if($(ПроцентОборачиваемостьПредГод) >= 1.05 ,'Arrow_NE_G.png', if($(ПроцентОборачиваемостьПредГод) >= 1,'Arrow_E_Y.png', if($(ПроцентОборачиваемостьПредГод) >= .95 ,'Arrow_W_Y.png', if($(ПроцентОборачиваемостьПредГод) >= .801  ,'Arrow_SE_R.png', if($(ПроцентОборачиваемостьПредГод) >= .80 ,'Arrow_S_R.png', if($(ПроцентОборачиваемостьПредГод) >= 0 ,'Arrow_S_R.png','Arrow_S_R.png') ))))))))",,
SET ТрендОборачиваемостьПредГод.Comment,Тренд оборачиваемости к предыдущему году,,
SET ТрендОстаткиПредГод,"if ($(ПроцентОстаткиПредГод) = 0 OR IsNull($(ПроцентОстаткиПредГод)), null(), 'qmem://<builtin>/' & if($(ПроцентОстаткиПредГод) >= 1.20,'Arrow_N_G.png', if($(ПроцентОстаткиПредГод) >= 1.051,'Arrow_NE_G.png', if($(ПроцентОстаткиПредГод) >= 1.05 ,'Arrow_NE_G.png', if($(ПроцентОстаткиПредГод) >= 1,'Arrow_E_Y.png', if($(ПроцентОстаткиПредГод) >= .95 ,'Arrow_W_Y.png', if($(ПроцентОстаткиПредГод) >= .801  ,'Arrow_SE_R.png', if($(ПроцентОстаткиПредГод) >= .80 ,'Arrow_S_R.png', if($(ПроцентОстаткиПредГод) >= 0 ,'Arrow_S_R.png','Arrow_S_R.png') ))))))))",,
SET ТрендОстаткиПредГод.Comment,Тренд остатков к предыдущему году,,
SET ТрендСуммаСкидкиПредГод,"if ($(ПроцентСуммаСкидкиТысПредГод) = 0 OR IsNull($(ПроцентСуммаСкидкиТысПредГод)), null(), 'qmem://<builtin>/' & if($(ПроцентСуммаСкидкиТысПредГод) >= 1.20,'Arrow_N_G.png', if($(ПроцентСуммаСкидкиТысПредГод) >= 1.051,'Arrow_NE_G.png', if($(ПроцентСуммаСкидкиТысПредГод) >= 1.05 ,'Arrow_NE_G.png', if($(ПроцентСуммаСкидкиТысПредГод) >= 1,'Arrow_E_Y.png', if($(ПроцентСуммаСкидкиТысПредГод) >= .95 ,'Arrow_W_Y.png', if($(ПроцентСуммаСкидкиТысПредГод) >= .801  ,'Arrow_SE_R.png', if($(ПроцентСуммаСкидкиТысПредГод) >= .80 ,'Arrow_S_R.png', if($(ПроцентСуммаСкидкиТысПредГод) >= 0 ,'Arrow_S_R.png','Arrow_S_R.png') ))))))))",,
SET ТрендСуммаСкидкиПредГод.Comment,Тренд суммы скидки к предыдущему году,,
SET ТрендПроцентСкидкиПредГод,"if ($(ПроцентПроцентСкидкиПредГод) = 0 OR IsNull($(ПроцентПроцентСкидкиПредГод)), null(), 'qmem://<builtin>/' & if($(ПроцентПроцентСкидкиПредГод) >= 1.20,'Arrow_N_G.png', if($(ПроцентПроцентСкидкиПредГод) >= 1.051,'Arrow_NE_G.png', if($(ПроцентПроцентСкидкиПредГод) >= 1.05 ,'Arrow_NE_G.png', if($(ПроцентПроцентСкидкиПредГод) >= 1,'Arrow_E_Y.png', if($(ПроцентПроцентСкидкиПредГод) >= .95 ,'Arrow_W_Y.png', if($(ПроцентПроцентСкидкиПредГод) >= .801  ,'Arrow_SE_R.png', if($(ПроцентПроцентСкидкиПредГод) >= .80 ,'Arrow_S_R.png', if($(ПроцентПроцентСкидкиПредГод) >= 0 ,'Arrow_S_R.png','Arrow_S_R.png') ))))))))",,
SET ТрендПроцентСкидкиПредГод.Comment,Тренд процента скидок к предыдущему году,,
SET КоличествоДней,=COUNT(DISTINCT {1<_ФлагДействующаяДата={1} $(ВыбранныеПоляКалендаря)>} Дата),,
SET КоличествоДнейВключаяБудущийПериод,=COUNT(DISTINCT {1<_ФлагДействующаяДата= $(ВыбранныеПоляКалендаря)>} Дата),,
SET ГруппаВыражение,$($(=Only({<ГП_$1={$2}>}  _ГП_$1))),,
SET ГруппаЗаголовок,$(=Only({<ГП_$1={$2}>}  _ГП_$1) & '.Заголовок'),,
SET ГруппаОписание,$(=Only({<ГП_$1={$2}>}  _ГП_$1) & '.Описание'),,
SET ГруппаВыражениеПредГодОтладка,Only({<ГП_$1={$(=chr(39) & Only({<ГП_ТипПоказателя={ПредГод}>} _ГП_ТипПоказателя) & chr(39))}>}  _ГП_$1),,
SET ГруппаВыражениеОтладка,Only({<ГП_$1={$2}>}  _ГП_$1),,
SET ПоказателиНесовместимы,"If(Count({<_ГП_Ошибки_$1={$2}>} _ГП_Ошибки_$1_ГруппаИзмерений)=0,0, If(MinString({<_ГП_Ошибки_$1={$2}>} _ГП_Ошибки_$1_ГруппаИзмерений)='*' AND GetSelectedCount(ВидДеятельности)>0, -1, Count({<_ГП_Ошибки_$1={$2},_ГП_Ошибки_$1_ГруппаИзмерений={'$(=Only(_ГруппаИзмерений))'}>} _ГП_Ошибки_$1_ГруппаИзмерений)=1))",,
SET ПоказателиНесовместимы.Label,ПоказателиНесовместимы,,
SET СкроллПоказатель,"aggr(Rank($(ГруппаВыражение(ПоказательАбс,'Факт')),4),$(=Only(_ГруппаИзмерений_Измерение)))",,
SET СкроллПоказатель.Label,СкроллПоказатель,,
SET СкроллВид,"(if(СкроллМакс-СкроллИзмерении<0,1,СкроллИзмерении-СкроллИзмерений2))",,
SET СкроллМакс,(Count(DISTINCT $(=Only(_ГруппаИзмерений_Измерение)))),,
SET ГруппаВыбрана,"IsNull(Only(_ГруппаПоказателей_$1)) = 0 AND Left(Only(_ГруппаПоказателей_$1),1) <> '―' AND Left(Only(_ГруппаПоказателей_$1),1) <> ' ' AND If($(ВыбранПлановыйПоказатель($1)),$(ГруппаИзмерений_План),-1)",,
SET ГруппаВыбрана.Comment,Формула для использовании в Show Condition. Примеры использования: $(ГруппаВыбрана(План)) $(ГруппаВыбрана(ПГ)),,
SET ГруппаВыбранаПоказатель,IsNull(Only(_ГруппаПоказателей_$1)) = 0,,
SET КрасныйШрифт,Num(Only({<ГП_$1={$2}>}  _ГП_$1_КраснаяГраница)),,
SET Проверка_Календаря," if( GetSelectedCount(Дата)>0,1, if (GetSelectedCount(Год)>0 and  (GetSelectedCount(Полугодие)>0 or GetSelectedCount(Квартал)>0 or GetSelectedCount(Месяц)>0 or GetSelectedCount(ГодПолугодие)>0 or GetSelectedCount(ГодКвартал)>0 or GetSelectedCount(ГодМесяц)>0 or GetSelectedCount(ГодНеделя)>0 or GetSelectedCount(День)>0 or GetSelectedCount(ДеньНедели)>0 or GetSelectedCount(ДеньИНомерНедели)>0 ) ,1,0))",,
SET Проверка_Календаря.Comment,Проверка_Календаря,,
SET Проверка_Календаря.Label,Проверка_Календаря,,
SET ГруппаИзмерений_План,"$(=if($(УстановленФильтрПоИзмерениюБезПлана),0,If(Only(_ГруппаИзмерений_Измерение)='[Классификатор товаров]', Only({<_ГруппаИзмерений={'$(=GetCurrentField([Классификатор товаров]))'}>} _ГруппаИзмерений_План), Only(_ГруппаИзмерений_План))))",,
SET ГруппаИзмерений_План.Comment,Условие отображения плановых показателей,,
SET ВыбранПлановыйПоказатель,$(=Only(_ГруппаПоказателей_$1) = 'План' or Only(_ГруппаПоказателей_$1) = '% изм. План-Факт' or Only(_ГруппаПоказателей_$1) = '∆ изм. План-Факт' or Only(_ГруппаПоказателей_$1) = 'План за  полный месяц'),,
SET УстановленФильтрПоИзмерениюБезПлана,$(=GetSelectedCount(Подкатегория)+GetSelectedCount(ВидДеятельности) +GetSelectedCount(Номенклатура)+GetSelectedCount(Клиент)),,
SET ВыбранПоказательСПланом,$(=Only(_ГруппаПоказателей_$1) = 'Продажи' OR  Only(_ГруппаПоказателей_$1) = 'Валовая прибыль'),,
SET ЗаголовокИзмерения,"Only(_ГруппаИзмерений) & Chr(10) & text('Выбрано: ' & Chr(10) &(GetCurrentSelections(Chr(10) ,'= ',',',30)))& Chr(10)",,
SET ЗаголовокИзмеренияФильтр,"Only(_ГруппаФильтр) & Chr(10) & text('Выбрано: ' & Chr(10) &(GetCurrentSelections(Chr(10) ,'= ',',',30)))& Chr(10)",,
SET ГруппаПланГраницаКрасного,"$(=if(_ГруппаПоказателей_План='% изм. План-Факт' or _ГруппаПоказателей_План='% изм. к пред (-1) год' or _ГруппаПоказателей_План='% изм. к пред (-2) год' or _ГруппаПоказателей_План='% изм. к пред (-1) месяц' ,0.8,0))",,
SET ГруппаПГГраницаКрасного,"$(=if(_ГруппаПоказателей_ПГ='% изм. План-Факт' or _ГруппаПоказателей_ПГ='% изм. к пред (-1) год' or _ГруппаПоказателей_ПГ='% изм. к пред (-2) год' or _ГруппаПоказателей_ПГ='% изм. к пред (-1) месяц',0.8,0))",,
SET ГруппаПланСкидкаГраницаКрасного,"$(=if(_ГруппаПоказателей_План='% изм. План-Факт' or _ГруппаПоказателей_План='% изм. к пред (-1) год' or _ГруппаПоказателей_План='% изм. к пред (-2) год' or _ГруппаПоказателей_План='% изм. к пред (-1) месяц',1.2,10000000000))",,
SET ГруппаПГСкидкаГраницаКрасного,"$(=if(_ГруппаПоказателей_ПГ='% изм. План-Факт' or _ГруппаПоказателей_ПГ='% изм. к пред (-1) год' or _ГруппаПоказателей_ПГ='% изм. к пред (-2) год' or _ГруппаПоказателей_ПГ='% изм. к пред (-1) месяц',1.2,10000000000))",,
SET ГруппаПланОстаткиГраницаКрасного,"$(=if(_ГруппаПоказателей_План='% изм. План-Факт' or _ГруппаПоказателей_План='% изм. к пред (-1) год' or _ГруппаПоказателей_План='% изм. к пред (-2) год' or _ГруппаПоказателей_План='% изм. к пред (-1) месяц',1.2,10000000000))",,
SET ГруппаПГОстаткиГраницаКрасного,"$(=if(_ГруппаПоказателей_ПГ='% изм. План-Факт' or _ГруппаПоказателей_ПГ='% изм. к пред (-1) год' or _ГруппаПоказателей_ПГ='% изм. к пред (-2) год' or _ГруппаПоказателей_ПГ='% изм. к пред (-1) месяц',1.2,10000000000))",,
SET ГруппаВыражениеПредГод2,$($(=Only({<ГП_$1={$(=chr(39) & Only({<ГП_ТипПоказателя={ПредГод2}>} _ГП_ТипПоказателя) & chr(39))}>}  _ГП_$1))),,
SET НормативOOS,"0,15",,
SET ТорговыеДни,"Money(Sum({<ТипДокумента={17}, ТипПериода={'Current'}>} Количество),'# ##0')",,
SET ТорговыеДни.Comment,Количество дней наличия на складе матричного товара на начало торгового дня (с учетом продаж),,
SET ТорговыеДни.Label,Торговые дни (матрица),,
SET ТорговыеДниРегламентные,"Money(Sum({<ТипДокумента={17}, ТипПериода={'Current'}>} Сумма),'# ##0')",,
SET ТорговыеДниРегламентные.Comment,Максимально возможное количество дней наличия на складе матричного товара,,
SET ТорговыеДниРегламентные.Label,Торговые дни регламентные (матрица),,
SET ДниДефицитаРегламентные,"Money(Sum({<ТипДокумента={17}, ТипПериода={'Current'}>} Себестоимость),'# ##0')",,
SET ДниДефицитаРегламентные.Comment,Количество дней отсутствия товара на складах,,
SET ДниДефицитаРегламентные.Label,Дни дефицита регламентные,,
SET OutOfStock,"Money((1-$(ТорговыеДни)/$(ТорговыеДниРегламентные)),'# ##0,00%')",,
SET OutOfStock.Comment,Out Of Stock (отношение в днях),,
SET OutOfStock.Label,%OOS,,
SET ТорговыеДниПредГод,"Money(Sum({<ТипДокумента={17}, ТипПериода={'Год'}>} Количество),'# ##0')",,
SET ТорговыеДниПредГод.Comment,Количество дней наличия на складе на начало торгового дня (с учетом продаж) пред год,,
SET ТорговыеДниПредГод.Label,Торговые дни пред год,,
SET ТорговыеДниРегламентныеПредГод,"Money(Sum({<ТипДокумента={17}, ТипПериода={'Год'}>} Сумма),'# ##0')",,
SET ТорговыеДниРегламентныеПредГод.Comment,Максимально возможное количество дней наличия на складе матричного товара пред год,,
SET ТорговыеДниРегламентныеПредГод.Label,Торговые дни регламентные пред год,,
SET ДниДефицитаРегламентныеПредГод,"Money(Sum({<ТипДокумента={17}, ТипПериода={'Год'}>} Себестоимость),'# ##0')",,
SET ДниДефицитаРегламентныеПредГод.Comment,Количество дней отсутствия товара на складах пред год,,
SET ДниДефицитаРегламентныеПредГод.Label,Дни дефицита регламентные,,
SET OutOfStockПредГод,"Money((1-$(ТорговыеДниПредГод)/$(ТорговыеДниРегламентныеПредГод)),'# ##0,00%')",,
SET OutOfStockПредГод.Comment,Out Of Stock (отношение в днях) пред год,,
SET OutOfStockПредГод.Label,%OOS пред год,,
SET ПроцентOutOfStockПредГод,"Money(Num($(OutOfStock)/$(OutOfStockПредГод),'# ##0,00%'),'# ##0,00%')",,
SET ПроцентOutOfStockПредГод.Comment,Процент от %OOS к предыдущему году,,
SET ПроцентOutOfStockПредГод.Label,%OOS к пред году,,
SET Тап_на_Вкладке_Остатки, 3,,
SET Тап_на_Вкладке_Остатки.Label,Тап_на_Вкладке_Остатки,,
SET Тап_АнализПродаж, 0,,
SET Тап_АнализПродаж.Label,ТТап_АнализПродаж,,
SET ЦветПлан,lightRed(),,
SET ЦветПлан.Label,ЦветПродаж,,
SET ЦветПрцПГ,green(),,
SET ЦветПрцПГ.Label,ЦветПродаж,,
SET ШрифтЦветПрцПГ,green(),,
SET ШрифтЦветПрцПГ.Label,ЦветПродаж,,
SET ЦветОшибки," rgb(214,231,248)",,
SET ЦветОшибки.Label,ЦветОшибки,,
SET ЦветПродаж," rgb(98,196,227)",,
SET ЦветПродаж.Label,ЦветПродаж,,
SET ЦветВП," rgb(173,194,214)",,
SET ЦветВП.Label,ЦветВП,,
SET ЦветОстатки," rgb(202,225,123)",,
SET ЦветОстатки.Label,ЦветОстатки,,
SET ЦветТрафик," rgb(202,115,123)",,
SET ЦветТрафик.Label,ЦветТрафик,,
SET ЦветКонверсия," rgb(202,200,123)",,
SET ЦветКонверсия.Label,ЦветКонверсия,,
SET ЦветКолСделок," rgb(0,172,172)",,
SET ЦветКолСделок.Label,ЦветСделок,,
SET ЦветСуммаОплаты," rgb(202,160,123)",,
SET ЦветСуммаОплаты.Label,ЦветСуммаОплаты,,
SET ЦветПенетрация," rgb(184,113,255)",,
SET ЦветПенетрация.Label,ЦветПенетрация,,
SET ЦветСрЧек," rgb(252,115,98)",,
SET ЦветСрЧек.Label,ЦветСрЧек,,
SET ЦветСуммаСкидки," rgb(210,210,0)",,
SET ЦветСуммаСкидки.Label,ЦветСуммаСкидки,,
SET ЦветПроцентСкидки," rgb(173,255,91)",,
SET ЦветПроцентСкидки.Label,ЦветПроцентСкидки,,
SET ЦветНаценка," rgb(20,255,20)",,
SET ЦветНаценка.Label,ЦветНаценка,,
SET ЦветОборачиваемость," rgb(120,200,220)",,
SET ЦветОборачиваемость.Label,ЦветОборачиваемость,,
SET ЦветПредГод," rgb(200,200,200)",,
SET ЦветПредГод.Label,ЦветПредГод,,
SET ЦветПредПредГод," rgb(220,220,200)",,
SET ЦветПредПредГод.Label,ЦветПредПредГод,,
SET ЦветПФ, red(),,
SET ЦветПФ.Label,ЦветПФ,,
SET ЦветПроцентПредГод,green(),,
SET ЦветПроцентПредГод.Label,ЦветПроцентПредГод,,
SET ЦветАктКнопки," rgb(102,255,140)",,
SET ЦветАктКнопки.Label,ЦветАктКнопки,,
SET ЦветНеАктКнопки," rgb(220,220,220)",,
SET ЦветНеАктКнопки.Label,ЦветНеАктКнопки,,
SET СкроллИзмерении,0,,
SET СкроллИзмерений2,15,,
SET Тап_на_Вкладке_Динамика,0,,
SET Тап_ВидДиаграммы,0,,
SET Показать,1,,
SET Скрыть,0,,
SET ПоляПоиска,"Номенклатура,Логист,МенеджерКатегории,МенеджерПродаж,Клиент,Бренд,Группа,Подгруппа,РекламнаяАкцияИстория",,
SET ЗаливкаПФ,"if ($1 <= 0 OR IsNull($1), rgb(255,255,255), if($1 >= 1.001,rgb(128,255,255), if($1 >= 0.95,rgb(128,255,128), if($1 >= 0.90 ,rgb(225,255,170), if($1 >= 0.8,rgb(255,182,147), if($1 >= 0 ,lightRed(),rgb(255,255,255)) )))))",,
SET ЗаливкаПФОбратная,"if ($1 <= 0 OR IsNull($1), rgb(255,255,255), if($1 <= 0.80,rgb(128,255,255), if($1 <= 0.90,rgb(128,255,128), if($1 <= 0.95 ,rgb(225,255,170), if($1 <= 1.0,rgb(255,182,147), if($1 <= 1000000 ,lightRed(190),rgb(255,255,255)) )))))",,
SET Заливка_ПФ_Продажи,"if ($(ПФ_Продажи) <= 0 OR IsNull($(ПФ_Продажи)), rgb(255,255,255), if($(ПФ_Продажи) >= 1.001,rgb(128,255,255), if($(ПФ_Продажи) >= 0.95,rgb(128,255,128), if($(ПФ_Продажи) >= 0.90 ,rgb(225,255,170), if($(ПФ_Продажи) >= 0.8,rgb(255,182,147), if($(ПФ_Продажи) >= 0 ,lightRed(),rgb(255,255,255)) )))))",,
SET Заливка_ПФ_ВП,"if ($(ПФ_ВП) <= 0 OR IsNull($(ПФ_ВП)), rgb(255,255,255), if($(ПФ_ВП) >= 1.001,rgb(128,255,255), if($(ПФ_ВП) >= 0.95,rgb(128,255,128), if($(ПФ_ВП) >= 0.90 ,rgb(225,255,170), if($(ПФ_ВП) >= 0.8,rgb(255,182,147), if($(ПФ_ВП) >= 0 ,lightRed(),rgb(255,255,255)) )))))",,
SET Заливка_ПФ_Наценка,"if ($(ПФРентВП) <= 0 OR IsNull($(ПФРентВП)), rgb(255,255,255), if($(ПФРентВП) >= 1.001,rgb(128,255,255), if($(ПФРентВП) >= 0.95,rgb(128,255,128), if($(ПФРентВП) >= 0.90 ,rgb(225,255,170), if($(ПФРентВП) >= 0.8,rgb(255,182,147), if($(ПФРентВП) >= 0 ,lightRed(),rgb(255,255,255)) )))))",,
SET Заливка_ПФ_Остатки,"if ($(ПФ_Остатки) <= 0 OR IsNull($(ПФ_Остатки)), rgb(255,255,255), if($(ПФ_Остатки) <= 0.80,rgb(128,255,255), if($(ПФ_Остатки) <= 0.90,rgb(128,255,128), if($(ПФ_Остатки) <= 0.95 ,rgb(225,255,170), if($(ПФ_Остатки) <= 1.0,rgb(255,182,147), if($(ПФ_Остатки) <= 1000000 ,lightRed(190),rgb(255,255,255)) )))))",,
SET Заливка_ПФ_Оборачиваемость,"if ($(ПФ_Оборачиваемость) <= 0 OR IsNull($(ПФ_Оборачиваемость)), rgb(255,255,255), if($(ПФ_Оборачиваемость) <= 0.80,rgb(128,255,255), if($(ПФ_Оборачиваемость) <= 0.90,rgb(128,255,128), if($(ПФ_Оборачиваемость) <= 0.95 ,rgb(225,255,170), if($(ПФ_Оборачиваемость) <= 1.0,rgb(255,182,147), if($(ПФ_Оборачиваемость) <= 1000000 ,lightRed(190),rgb(255,255,255)) )))))",,
SET ЦветВычКолонки," rgb(230,230,230)",,
SET ЦветВычКолонки.Label,ЦветВычКолонки,,
SET ШрифтЦветПФ,Red(),,
SET ШрифтЦветПФ.Label,ЦветПродаж,,
SET ШрифтЦветПлан,"rgb(255,255,255)",,
SET ШрифтЦветПлан.Label,ЦветПродаж,,
SET ШрифтЦветПродаж,"rgb(255,255,255)",,
SET ШрифтЦветПродаж.Label,ЦветПродаж,,
SET ШрифтЦветВП," rgb(255,255,255)",,
SET ШрифтЦветВП.Label,ШрифтЦветВП,,
SET ШрифтЦветОстатки," rgb(80,80,80)",,
SET ШрифтЦветОстатки.Label,ЦветОстатки,,
SET ШрифтЦветТрафик," rgb(255,255,255)",,
SET ШрифтЦветТрафик.Label,ЦветТрафик,,
SET ШрифтЦветКонверсия," rgb(80,80,80)",,
SET ШрифтЦветКонверсия.Label,ЦветКонверсия,,
SET ШрифтЦветКолСделок," rgb(255,255,255)",,
SET ШрифтЦветКолСделок.Label,ЦветСделок,,
SET ШрифтЦветСуммаОплаты," rgb(255,255,255)",,
SET ШрифтЦветСуммаОплаты.Label,ЦветСуммаОплаты,,
SET ШрифтЦветПенетрация," rgb(80,80,80)",,
SET ШрифтЦветПенетрация.Label,ЦветПенетрация,,
SET ШрифтЦветСрЧек," rgb(80,80,80)",,
SET ШрифтЦветСрЧек.Label,ЦветСрЧек,,
SET ШрифтЦветСуммаСкидки," rgb(80,80,80)",,
SET ШрифтЦветСуммаСкидки.Label,ЦветСуммаСкидки,,
SET ШрифтЦветПроцентСкидки," rgb(80,80,80)",,
SET ШрифтЦветПроцентСкидки.Label,ЦветПроцентСкидки,,
SET ШрифтЦветНаценка," rgb(80,80,80)",,
SET ШрифтЦветНаценка.Label,ЦветНаценка,,
SET ШрифтЦветОборачиваемость," rgb(80,80,80)",,
SET ШрифтЦветОборачиваемость.Label,ЦветОборачиваемость,,
SET ШрифтЦветПредГод," rgb(80,80,80)",,
SET ШрифтЦветПредГод.Label,ЦветПредГод,,
SET ШрифтЦветПредПредГод," rgb(80,80,80)",,
SET ШрифтЦветПредПредГод.Label,ЦветПредПредГод,,
SET ТОППодгрупп,20,,
SET ТОППодгрупп.Label,Топ подгрупп,,
SET ПродажаПроверкаФакт,"Money(Sum({$<ТипДокумента = {7},ТипПериода={'Current'}>}Сумма),'# ##0,00')",,
SET ПродажаПроверкаФакт.Comment,Проверка - суммы продажи из Excel,,
SET ПродажаПроверкаФакт.Label,Проверка продажи ИТОГО,,
SET ПродажаПроверкаРасхождение,"Money($(СуммаПродажи) - $(ПродажаПроверкаФакт),'# ##0,00')",,
SET ПродажаПроверкаРасхождение.Comment,Расхождение с Excel по сумме продаж,,
SET ПродажаПроверкаРасхождение.Label,Проверка продажи расхождение,,
SET ВППроверкаФакт,"Money(Sum({$<ТипДокумента = {7},ТипПериода={'Current'}>}ВП),'# ##0,00')",,
SET ВППроверкаФакт.Comment,Проверка - суммы ВП из Excel,,
SET ВППроверкаФакт.Label,Проверка ВП ИТОГО,,
SET ВППроверкаРасхождение,"Money($(СуммаВП) - $(ВППроверкаФакт),'# ##0,00')",,
SET ВППроверкаРасхождение.Comment,Расхождение с Excel по ВП,,
SET ВППроверкаРасхождение.Label,Проверка ВП расхождение,,
SET Динамика,0,,
SET periodSetMode,0,,
LET periodStart,MakeDate(2014),,
LET periodEnd,MakeDate(2014),,
LET Детально,0,,
SET КоличествоСКУМатричныхОстаток,"Count({<_ТипДокумента={11},МатричныйТовар={'Матричный'}, _МесяцПоПорядку={'$(=Max({<_ФлагДействующаяДата={1}>} _МесяцПоПорядку))'}, Количество ={'>0'},ТипПериода={'Current'}>} DISTINCT КодНоменклатуры)",,
SET КоличествоСКУМатричныхОстаток.Comment,Количество матричных SKU на остатке,,
SET КоличествоСКУМатричныхОстаток.Label,Кол матричных SKU на остатке,,
SET КоличествоСКУМатричных,Count({<МатричныйТовар={'Матричный'}>} DISTINCT КодНоменклатуры),,
SET КоличествоСКУМатричных.Comment,Количество матричных SKU план,,
SET КоличествоСКУМатричных.Label,Кол матричных SKU план,,
SET SalesSum,Sum({<OperationType={Sale}>} Amount),,
SET SalesSum.Comment,Sales amount,,
SET SalesSum.Label,Sales,,
SET CostSum,Sum({<OperationType={Cost}>} Amount),,
SET CostSum.Comment,Cost amount,,
SET CostSum.Label,Cost,,
SET MarginAmout,($(SalesSum) - $(CostSum)),,
SET MarginAmout.Comment,Margin amount,,
SET MarginAmout.Label,Margin,,
''';
    var reader = new qv.Reader()..readFile('CustomVariables.qsv',code);
    reader.outputErrors();
    expect(reader.errors.isEmpty,isTrue);
  });


}